@@ -77,6 +77,9 @@ def help_cmd(context):
             print('  parent')
             print('     - checkout parent version branch "{}"'.format(context['parent_version_branch']))
 
+        print('  cleanup')
+        print('     - remove any local branches that have been merged to "{}"'.format(context['current_branch']))
+        print('     - remove any refs to remote branches that have been removed')
         print('  version')
         print('     - show current gitty version ({})'.format(context['gitty_version']))
 
@@ -142,12 +145,47 @@ def command_handler(context):
         'v': version,
         'version': version,
         'p': parent,
-        'parent': parent
+        'parent': parent,
+        'c': cleanup,
+        'clean': cleanup,
+        'cleanup': cleanup
     }
     print("command:", context['command'])
     switcher.get(context['command'])(context)
 
 
+def cleanup(context):
+    # show(context)
+    # git branch --no-color --merged
+    response = execute_command(context, 'git status -s'.split())
+    if response:
+        # this repo isn't "clean", so don't continue...
+        print(response.decode())
+        print('aborting cleanup process - repository has outstanding changes')
+        return
+    execute_command(context, 'git fetch --all --prune'.split())
+    execute_command(context, 'git pull --rebase'.split())
+    command_output = execute_command(context, 'git branch --no-color --merged'.split())
+    output_decoded = command_output.decode('utf-8')
+    output_lines = output_decoded.splitlines()
+    for line in output_lines:
+        branch_name = line.split()[-1]
+
+        retain_reason = ''
+        if branch_name.endswith('/master') or branch_name == 'master':
+            retain_reason = 'master branches are preserved'
+        if branch_name.endswith('/releases'):
+            retain_reason = 'release branches are preserved'
+        if branch_name == context['current_branch']:
+            retain_reason = 'current branch is preserved'
+
+        if not retain_reason:
+            execute_command(context, 'git branch -d {}'.format(branch_name).split())
+        else:
+            print('leaving branch "{}" ({})'.format(branch_name, retain_reason))
+    return
+
+
 def parent(context):
     execute_command(context, 'git checkout {}'.format(context['parent_version_branch']).split())
 
@@ -260,7 +298,7 @@ def execute_command(context, command):
 
     if not context['dry_run']:
         try:
-            subprocess.check_output(command)
+            return subprocess.check_output(command)
         except subprocess.CalledProcessError as e:
             print(str(e.output))
         # finished = output.split('\n')
